@@ -1,19 +1,15 @@
 #!/usr/bin/env python
-
-import sys
-import os
 import signal
-import argparse
-import json
+import sys
+
 from zenlog import log
 
-from radioactive.args import Parser
-from radioactive.app_version import get_version
 from radioactive.alias import Alias
+from radioactive.app_version import get_version
+from radioactive.args import Parser
 from radioactive.handler import Handler
-from radioactive.player import Player
 from radioactive.last_station import Last_station
-
+from radioactive.player import Player
 
 # globally needed as signal handler needs it
 # to terminate main() properly
@@ -46,14 +42,16 @@ def main():
         log.level(log_level)
     else:
         log.level("info")
-        log.warning("Correct log levels are: error,warning,info(default),debug")
+        log.warning(
+            "Correct log levels are: error,warning,info(default),debug")
 
     # -------------------- NOTHING PROVIDED --------------------- #
     # if neither of --station and --uuid provided , look in last_station file
 
     if station_name is None and station_uuid is None:
         # try to fetch the last played station's information
-        log.warn("No station information provided, trying to get the last station")
+        log.warn(
+            "No station information provided, trying to get the last station")
         # getting last station details, getting the UUID
         station_uuid = last_station.get_info()
 
@@ -76,7 +74,7 @@ def main():
         if result is not None and alias.found:
             station_uuid = result["stationuuid"]
 
-        if alias.found == True:
+        if alias.found:
             mode_of_search = "uuid"
         else:
             log.debug("Alias not found, using normal API search")
